"""CylindricalGearMeshLoadedContactPoint"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)
from mastapy._private._math.vector_2d import Vector2D

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.gears.ltca import _970

_CYLINDRICAL_GEAR_MESH_LOADED_CONTACT_POINT = python_net_import(
    "SMT.MastaAPI.Gears.LTCA.Cylindrical", "CylindricalGearMeshLoadedContactPoint"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.gear_designs.cylindrical import _1157
    from mastapy._private.gears.ltca.cylindrical import _983
    from mastapy._private.gears.rating.cylindrical.iso6336 import _639
    from mastapy._private.materials import _369

    Self = TypeVar("Self", bound="CylindricalGearMeshLoadedContactPoint")
    CastSelf = TypeVar(
        "CastSelf",
        bound="CylindricalGearMeshLoadedContactPoint._Cast_CylindricalGearMeshLoadedContactPoint",
    )


__docformat__ = "restructuredtext en"
__all__ = ("CylindricalGearMeshLoadedContactPoint",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CylindricalGearMeshLoadedContactPoint:
    """Special nested class for casting CylindricalGearMeshLoadedContactPoint to subclasses."""

    __parent__: "CylindricalGearMeshLoadedContactPoint"

    @property
    def gear_mesh_loaded_contact_point(
        self: "CastSelf",
    ) -> "_970.GearMeshLoadedContactPoint":
        return self.__parent__._cast(_970.GearMeshLoadedContactPoint)

    @property
    def cylindrical_gear_mesh_loaded_contact_point(
        self: "CastSelf",
    ) -> "CylindricalGearMeshLoadedContactPoint":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class CylindricalGearMeshLoadedContactPoint(_970.GearMeshLoadedContactPoint):
    """CylindricalGearMeshLoadedContactPoint

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CYLINDRICAL_GEAR_MESH_LOADED_CONTACT_POINT

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def coefficient_of_friction(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "CoefficientOfFriction")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def depth_of_maximum_material_exposure_gear_aiso633642019(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "DepthOfMaximumMaterialExposureGearAISO633642019"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def depth_of_maximum_material_exposure_gear_biso633642019(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "DepthOfMaximumMaterialExposureGearBISO633642019"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def face_width_position_gear_a(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "FaceWidthPositionGearA")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def face_width_position_gear_b(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "FaceWidthPositionGearB")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def is_gear_a_tip_contact_point(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "IsGearATipContactPoint")

        if temp is None:
            return False

        return temp

    @property
    @exception_bridge
    def is_gear_b_tip_contact_point(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "IsGearBTipContactPoint")

        if temp is None:
            return False

        return temp

    @property
    @exception_bridge
    def is_tip_contact_point(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "IsTipContactPoint")

        if temp is None:
            return False

        return temp

    @property
    @exception_bridge
    def lubrication_state_d_value(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "LubricationStateDValue")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def maximum_material_exposure_gear_aiso633642019(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "MaximumMaterialExposureGearAISO633642019"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def maximum_material_exposure_gear_biso633642019(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "MaximumMaterialExposureGearBISO633642019"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def micropitting_contact_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MicropittingContactTemperature")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def micropitting_flash_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MicropittingFlashTemperature")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def micropitting_minimum_lubricant_film_thickness(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "MicropittingMinimumLubricantFilmThickness"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def micropitting_safety_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MicropittingSafetyFactor")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def micropitting_specific_lubricant_film_thickness(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "MicropittingSpecificLubricantFilmThickness"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def minimum_lubricant_film_thickness_dowson(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "MinimumLubricantFilmThicknessDowson"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def pressure_velocity_pv(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "PressureVelocityPV")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def scuffing_contact_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ScuffingContactTemperature")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def scuffing_contact_temperature_agma925a03(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "ScuffingContactTemperatureAGMA925A03"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def scuffing_contact_temperature_agma925b22(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "ScuffingContactTemperatureAGMA925B22"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def scuffing_contact_temperature_din399041987(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "ScuffingContactTemperatureDIN399041987"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def scuffing_flash_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ScuffingFlashTemperature")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def scuffing_flash_temperature_agma925a03(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "ScuffingFlashTemperatureAGMA925A03"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def scuffing_flash_temperature_agma925b22(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "ScuffingFlashTemperatureAGMA925B22"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def scuffing_flash_temperature_din399041987(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "ScuffingFlashTemperatureDIN399041987"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def scuffing_safety_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ScuffingSafetyFactor")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def scuffing_safety_factor_agma925a03(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ScuffingSafetyFactorAGMA925A03")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def scuffing_safety_factor_agma925b22(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ScuffingSafetyFactorAGMA925B22")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def scuffing_safety_factor_din399041987(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ScuffingSafetyFactorDIN399041987")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def sliding_power_loss(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SlidingPowerLoss")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def sliding_velocity(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SlidingVelocity")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_a_profile_measurement(
        self: "Self",
    ) -> "_1157.CylindricalGearProfileMeasurement":
        """mastapy.gears.gear_designs.cylindrical.CylindricalGearProfileMeasurement

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearAProfileMeasurement")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def gear_b_profile_measurement(
        self: "Self",
    ) -> "_1157.CylindricalGearProfileMeasurement":
        """mastapy.gears.gear_designs.cylindrical.CylindricalGearProfileMeasurement

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearBProfileMeasurement")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def lubrication_detail(self: "Self") -> "_369.LubricationDetail":
        """mastapy.materials.LubricationDetail

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "LubricationDetail")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def tooth_flank_fracture_analysis_gear_a(
        self: "Self",
    ) -> "_639.ToothFlankFractureAnalysisContactPointMethodA":
        """mastapy.gears.rating.cylindrical.iso6336.ToothFlankFractureAnalysisContactPointMethodA

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ToothFlankFractureAnalysisGearA")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def tooth_flank_fracture_analysis_gear_b(
        self: "Self",
    ) -> "_639.ToothFlankFractureAnalysisContactPointMethodA":
        """mastapy.gears.rating.cylindrical.iso6336.ToothFlankFractureAnalysisContactPointMethodA

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ToothFlankFractureAnalysisGearB")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def contact_line(self: "Self") -> "_983.CylindricalGearMeshLoadedContactLine":
        """mastapy.gears.ltca.cylindrical.CylindricalGearMeshLoadedContactLine

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ContactLine")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def gear_a_point_in_face_width_roll_distance(self: "Self") -> "Vector2D":
        """Vector2D

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearAPointInFaceWidthRollDistance")

        if temp is None:
            return None

        value = conversion.pn_to_mp_vector2d(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def gear_b_point_in_face_width_roll_distance(self: "Self") -> "Vector2D":
        """Vector2D

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearBPointInFaceWidthRollDistance")

        if temp is None:
            return None

        value = conversion.pn_to_mp_vector2d(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_CylindricalGearMeshLoadedContactPoint":
        """Cast to another type.

        Returns:
            _Cast_CylindricalGearMeshLoadedContactPoint
        """
        return _Cast_CylindricalGearMeshLoadedContactPoint(self)



"""RigidConnectorStiffnessType"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal.python_net import python_net_import

_RIGID_CONNECTOR_STIFFNESS_TYPE = python_net_import(
    "SMT.MastaAPI.SystemModel.PartModel.Couplings", "RigidConnectorStiffnessType"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="RigidConnectorStiffnessType")
    CastSelf = TypeVar(
        "CastSelf",
        bound="RigidConnectorStiffnessType._Cast_RigidConnectorStiffnessType",
    )


__docformat__ = "restructuredtext en"
__all__ = ("RigidConnectorStiffnessType",)


class RigidConnectorStiffnessType(Enum):
    """RigidConnectorStiffnessType

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _RIGID_CONNECTOR_STIFFNESS_TYPE

    SIMPLE = 0
    SPECIFY_MATRIX = 1
    NONLINEAR = 2
    INDIVIDUAL_CONTACTS = 3


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


RigidConnectorStiffnessType.__setattr__ = __enum_setattr
RigidConnectorStiffnessType.__delattr__ = __enum_delattr



"""DynamicTorqueVector3DResult"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private import _0
from mastapy._private._internal import constructor, utility

_DYNAMIC_TORQUE_VECTOR_3D_RESULT = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses.Reporting",
    "DynamicTorqueVector3DResult",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results.mbd_analyses.reporting import (
        _5866,
    )

    Self = TypeVar("Self", bound="DynamicTorqueVector3DResult")
    CastSelf = TypeVar(
        "CastSelf",
        bound="DynamicTorqueVector3DResult._Cast_DynamicTorqueVector3DResult",
    )


__docformat__ = "restructuredtext en"
__all__ = ("DynamicTorqueVector3DResult",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_DynamicTorqueVector3DResult:
    """Special nested class for casting DynamicTorqueVector3DResult to subclasses."""

    __parent__: "DynamicTorqueVector3DResult"

    @property
    def dynamic_torque_vector_3d_result(
        self: "CastSelf",
    ) -> "DynamicTorqueVector3DResult":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class DynamicTorqueVector3DResult(_0.APIBase):
    """DynamicTorqueVector3DResult

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _DYNAMIC_TORQUE_VECTOR_3D_RESULT

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def magnitude(self: "Self") -> "_5866.DynamicTorqueResultAtTime":
        """mastapy.system_model.analyses_and_results.mbd_analyses.reporting.DynamicTorqueResultAtTime

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Magnitude")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def radial_magnitude(self: "Self") -> "_5866.DynamicTorqueResultAtTime":
        """mastapy.system_model.analyses_and_results.mbd_analyses.reporting.DynamicTorqueResultAtTime

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RadialMagnitude")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def x(self: "Self") -> "_5866.DynamicTorqueResultAtTime":
        """mastapy.system_model.analyses_and_results.mbd_analyses.reporting.DynamicTorqueResultAtTime

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "X")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def y(self: "Self") -> "_5866.DynamicTorqueResultAtTime":
        """mastapy.system_model.analyses_and_results.mbd_analyses.reporting.DynamicTorqueResultAtTime

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Y")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def z(self: "Self") -> "_5866.DynamicTorqueResultAtTime":
        """mastapy.system_model.analyses_and_results.mbd_analyses.reporting.DynamicTorqueResultAtTime

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Z")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_DynamicTorqueVector3DResult":
        """Cast to another type.

        Returns:
            _Cast_DynamicTorqueVector3DResult
        """
        return _Cast_DynamicTorqueVector3DResult(self)



"""ConceptRadialClearanceBearing"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.overridable_constructor import _unpack_overridable
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_get_with_method,
    pythonnet_property_set,
    pythonnet_property_set_with_method,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._internal.implicit import overridable
from mastapy._private.bearings.bearing_designs.concept import _2447

_DATABASE_WITH_SELECTED_ITEM = python_net_import(
    "SMT.MastaAPI.UtilityGUI.Databases", "DatabaseWithSelectedItem"
)
_CONCEPT_RADIAL_CLEARANCE_BEARING = python_net_import(
    "SMT.MastaAPI.Bearings.BearingDesigns.Concept", "ConceptRadialClearanceBearing"
)

if TYPE_CHECKING:
    from typing import Any, Tuple, Type, TypeVar, Union

    from mastapy._private.bearings import _2116
    from mastapy._private.bearings.bearing_designs import _2378, _2382

    Self = TypeVar("Self", bound="ConceptRadialClearanceBearing")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ConceptRadialClearanceBearing._Cast_ConceptRadialClearanceBearing",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ConceptRadialClearanceBearing",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ConceptRadialClearanceBearing:
    """Special nested class for casting ConceptRadialClearanceBearing to subclasses."""

    __parent__: "ConceptRadialClearanceBearing"

    @property
    def concept_clearance_bearing(self: "CastSelf") -> "_2447.ConceptClearanceBearing":
        return self.__parent__._cast(_2447.ConceptClearanceBearing)

    @property
    def non_linear_bearing(self: "CastSelf") -> "_2382.NonLinearBearing":
        from mastapy._private.bearings.bearing_designs import _2382

        return self.__parent__._cast(_2382.NonLinearBearing)

    @property
    def bearing_design(self: "CastSelf") -> "_2378.BearingDesign":
        from mastapy._private.bearings.bearing_designs import _2378

        return self.__parent__._cast(_2378.BearingDesign)

    @property
    def concept_radial_clearance_bearing(
        self: "CastSelf",
    ) -> "ConceptRadialClearanceBearing":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ConceptRadialClearanceBearing(_2447.ConceptClearanceBearing):
    """ConceptRadialClearanceBearing

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CONCEPT_RADIAL_CLEARANCE_BEARING

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def bore(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "Bore")

        if temp is None:
            return 0.0

        return temp

    @bore.setter
    @exception_bridge
    @enforce_parameter_types
    def bore(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "Bore", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def contact_angle(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "ContactAngle")

        if temp is None:
            return 0.0

        return temp

    @contact_angle.setter
    @exception_bridge
    @enforce_parameter_types
    def contact_angle(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "ContactAngle", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def contact_diameter_derived_from_connection_geometry(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(
            self.wrapped, "ContactDiameterDerivedFromConnectionGeometry"
        )

        if temp is None:
            return False

        return temp

    @contact_diameter_derived_from_connection_geometry.setter
    @exception_bridge
    @enforce_parameter_types
    def contact_diameter_derived_from_connection_geometry(
        self: "Self", value: "bool"
    ) -> None:
        pythonnet_property_set(
            self.wrapped,
            "ContactDiameterDerivedFromConnectionGeometry",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def end_angle(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "EndAngle")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @end_angle.setter
    @exception_bridge
    @enforce_parameter_types
    def end_angle(self: "Self", value: "Union[float, Tuple[float, bool]]") -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "EndAngle", value)

    @property
    @exception_bridge
    def has_stiffness_only_in_eccentricity_direction(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(
            self.wrapped, "HasStiffnessOnlyInEccentricityDirection"
        )

        if temp is None:
            return False

        return temp

    @has_stiffness_only_in_eccentricity_direction.setter
    @exception_bridge
    @enforce_parameter_types
    def has_stiffness_only_in_eccentricity_direction(
        self: "Self", value: "bool"
    ) -> None:
        pythonnet_property_set(
            self.wrapped,
            "HasStiffnessOnlyInEccentricityDirection",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def inner_component_material_selector(self: "Self") -> "str":
        """str"""
        temp = pythonnet_property_get_with_method(
            self.wrapped, "InnerComponentMaterialSelector", "SelectedItemName"
        )

        if temp is None:
            return ""

        return temp

    @inner_component_material_selector.setter
    @exception_bridge
    @enforce_parameter_types
    def inner_component_material_selector(self: "Self", value: "str") -> None:
        pythonnet_property_set_with_method(
            self.wrapped,
            "InnerComponentMaterialSelector",
            "SetSelectedItem",
            str(value) if value is not None else "",
        )

    @property
    @exception_bridge
    def model(self: "Self") -> "_2116.BearingModel":
        """mastapy.bearings.BearingModel

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Model")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(temp, "SMT.MastaAPI.Bearings.BearingModel")

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.bearings._2116", "BearingModel"
        )(value)

    @property
    @exception_bridge
    def outer_component_material_selector(self: "Self") -> "str":
        """str"""
        temp = pythonnet_property_get_with_method(
            self.wrapped, "OuterComponentMaterialSelector", "SelectedItemName"
        )

        if temp is None:
            return ""

        return temp

    @outer_component_material_selector.setter
    @exception_bridge
    @enforce_parameter_types
    def outer_component_material_selector(self: "Self", value: "str") -> None:
        pythonnet_property_set_with_method(
            self.wrapped,
            "OuterComponentMaterialSelector",
            "SetSelectedItem",
            str(value) if value is not None else "",
        )

    @property
    @exception_bridge
    def outer_diameter(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "OuterDiameter")

        if temp is None:
            return 0.0

        return temp

    @outer_diameter.setter
    @exception_bridge
    @enforce_parameter_types
    def outer_diameter(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "OuterDiameter", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def start_angle(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "StartAngle")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @start_angle.setter
    @exception_bridge
    @enforce_parameter_types
    def start_angle(self: "Self", value: "Union[float, Tuple[float, bool]]") -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "StartAngle", value)

    @property
    def cast_to(self: "Self") -> "_Cast_ConceptRadialClearanceBearing":
        """Cast to another type.

        Returns:
            _Cast_ConceptRadialClearanceBearing
        """
        return _Cast_ConceptRadialClearanceBearing(self)



"""RootAssemblyCompoundSystemDeflection"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.system_deflections.compound import (
    _3154,
)

_ROOT_ASSEMBLY_COMPOUND_SYSTEM_DEFLECTION = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections.Compound",
    "RootAssemblyCompoundSystemDeflection",
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.gears.gear_designs.cylindrical.micro_geometry import _1235
    from mastapy._private.system_model.analyses_and_results import _2944
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7941,
        _7944,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound import (
        _4579,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections import (
        _3095,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound import (
        _3147,
        _3199,
        _3229,
    )
    from mastapy._private.system_model.fe import _2675
    from mastapy._private.utility_gui.charts import _2106

    Self = TypeVar("Self", bound="RootAssemblyCompoundSystemDeflection")
    CastSelf = TypeVar(
        "CastSelf",
        bound="RootAssemblyCompoundSystemDeflection._Cast_RootAssemblyCompoundSystemDeflection",
    )


__docformat__ = "restructuredtext en"
__all__ = ("RootAssemblyCompoundSystemDeflection",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_RootAssemblyCompoundSystemDeflection:
    """Special nested class for casting RootAssemblyCompoundSystemDeflection to subclasses."""

    __parent__: "RootAssemblyCompoundSystemDeflection"

    @property
    def assembly_compound_system_deflection(
        self: "CastSelf",
    ) -> "_3154.AssemblyCompoundSystemDeflection":
        return self.__parent__._cast(_3154.AssemblyCompoundSystemDeflection)

    @property
    def abstract_assembly_compound_system_deflection(
        self: "CastSelf",
    ) -> "_3147.AbstractAssemblyCompoundSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections.compound import (
            _3147,
        )

        return self.__parent__._cast(_3147.AbstractAssemblyCompoundSystemDeflection)

    @property
    def part_compound_system_deflection(
        self: "CastSelf",
    ) -> "_3229.PartCompoundSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections.compound import (
            _3229,
        )

        return self.__parent__._cast(_3229.PartCompoundSystemDeflection)

    @property
    def part_compound_analysis(self: "CastSelf") -> "_7944.PartCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7944,
        )

        return self.__parent__._cast(_7944.PartCompoundAnalysis)

    @property
    def design_entity_compound_analysis(
        self: "CastSelf",
    ) -> "_7941.DesignEntityCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7941,
        )

        return self.__parent__._cast(_7941.DesignEntityCompoundAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def root_assembly_compound_system_deflection(
        self: "CastSelf",
    ) -> "RootAssemblyCompoundSystemDeflection":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class RootAssemblyCompoundSystemDeflection(_3154.AssemblyCompoundSystemDeflection):
    """RootAssemblyCompoundSystemDeflection

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ROOT_ASSEMBLY_COMPOUND_SYSTEM_DEFLECTION

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def duty_cycle_efficiency_results(
        self: "Self",
    ) -> "_3199.DutyCycleEfficiencyResults":
        """mastapy.system_model.analyses_and_results.system_deflections.compound.DutyCycleEfficiencyResults

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "DutyCycleEfficiencyResults")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def root_assembly_compound_power_flow(
        self: "Self",
    ) -> "_4579.RootAssemblyCompoundPowerFlow":
        """mastapy.system_model.analyses_and_results.power_flows.compound.RootAssemblyCompoundPowerFlow

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RootAssemblyCompoundPowerFlow")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def assembly_analysis_cases_ready(
        self: "Self",
    ) -> "List[_3095.RootAssemblySystemDeflection]":
        """List[mastapy.system_model.analyses_and_results.system_deflections.RootAssemblySystemDeflection]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AssemblyAnalysisCasesReady")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def bearing_race_f_es(self: "Self") -> "List[_2675.RaceBearingFESystemDeflection]":
        """List[mastapy.system_model.fe.RaceBearingFESystemDeflection]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "BearingRaceFEs")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def assembly_analysis_cases(
        self: "Self",
    ) -> "List[_3095.RootAssemblySystemDeflection]":
        """List[mastapy.system_model.analyses_and_results.system_deflections.RootAssemblySystemDeflection]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AssemblyAnalysisCases")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @exception_bridge
    @enforce_parameter_types
    def peak_to_peak_transmission_error_chart(
        self: "Self",
        mesh_duty_cycles: "List[_1235.CylindricalGearMeshMicroGeometryDutyCycle]",
        header: "str",
        x_axis_title: "str",
        y_axis_title: "str",
    ) -> "_2106.TwoDChartDefinition":
        """mastapy.utility_gui.charts.TwoDChartDefinition

        Args:
            mesh_duty_cycles (List[mastapy.gears.gear_designs.cylindrical.micro_geometry.CylindricalGearMeshMicroGeometryDutyCycle])
            header (str)
            x_axis_title (str)
            y_axis_title (str)
        """
        mesh_duty_cycles = conversion.mp_to_pn_objects_in_dotnet_list(mesh_duty_cycles)
        header = str(header)
        x_axis_title = str(x_axis_title)
        y_axis_title = str(y_axis_title)
        method_result = pythonnet_method_call(
            self.wrapped,
            "PeakToPeakTransmissionErrorChart",
            mesh_duty_cycles,
            header if header else "",
            x_axis_title if x_axis_title else "",
            y_axis_title if y_axis_title else "",
        )
        if method_result is None:
            return None

        type_ = method_result.GetType()
        return constructor.new(type_.Namespace, type_.Name)(method_result)

    @property
    def cast_to(self: "Self") -> "_Cast_RootAssemblyCompoundSystemDeflection":
        """Cast to another type.

        Returns:
            _Cast_RootAssemblyCompoundSystemDeflection
        """
        return _Cast_RootAssemblyCompoundSystemDeflection(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3810 import (
        AbstractAssemblySteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3811 import (
        AbstractShaftOrHousingSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3812 import (
        AbstractShaftSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3813 import (
        AbstractShaftToMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3814 import (
        AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3815 import (
        AGMAGleasonConicalGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3816 import (
        AGMAGleasonConicalGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3817 import (
        AssemblySteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3818 import (
        BearingSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3819 import (
        BeltConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3820 import (
        BeltDriveSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3821 import (
        BevelDifferentialGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3822 import (
        BevelDifferentialGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3823 import (
        BevelDifferentialGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3824 import (
        BevelDifferentialPlanetGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3825 import (
        BevelDifferentialSunGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3826 import (
        BevelGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3827 import (
        BevelGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3828 import (
        BevelGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3829 import (
        BoltedJointSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3830 import (
        BoltSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3831 import (
        ClutchConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3832 import (
        ClutchHalfSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3833 import (
        ClutchSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3834 import (
        CoaxialConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3835 import (
        ComponentSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3836 import (
        ConceptCouplingConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3837 import (
        ConceptCouplingHalfSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3838 import (
        ConceptCouplingSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3839 import (
        ConceptGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3840 import (
        ConceptGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3841 import (
        ConceptGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3842 import (
        ConicalGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3843 import (
        ConicalGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3844 import (
        ConicalGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3845 import (
        ConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3846 import (
        ConnectorSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3847 import (
        CouplingConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3848 import (
        CouplingHalfSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3849 import (
        CouplingSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3850 import (
        CVTBeltConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3851 import (
        CVTPulleySteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3852 import (
        CVTSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3853 import (
        CycloidalAssemblySteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3854 import (
        CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3855 import (
        CycloidalDiscPlanetaryBearingConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3856 import (
        CycloidalDiscSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3857 import (
        CylindricalGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3858 import (
        CylindricalGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3859 import (
        CylindricalGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3860 import (
        CylindricalPlanetGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3861 import (
        DatumSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3862 import (
        ExternalCADModelSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3863 import (
        FaceGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3864 import (
        FaceGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3865 import (
        FaceGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3866 import (
        FEPartSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3867 import (
        FlexiblePinAssemblySteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3868 import (
        GearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3869 import (
        GearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3870 import (
        GearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3871 import (
        GuideDxfModelSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3872 import (
        HypoidGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3873 import (
        HypoidGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3874 import (
        HypoidGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3875 import (
        InterMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3876 import (
        KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3877 import (
        KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3878 import (
        KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3879 import (
        KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3880 import (
        KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3881 import (
        KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3882 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3883 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3884 import (
        KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3885 import (
        MassDiscSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3886 import (
        MeasurementComponentSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3887 import (
        MicrophoneArraySteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3888 import (
        MicrophoneSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3889 import (
        MountableComponentSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3890 import (
        OilSealSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3891 import (
        PartSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3892 import (
        PartToPartShearCouplingConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3893 import (
        PartToPartShearCouplingHalfSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3894 import (
        PartToPartShearCouplingSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3895 import (
        PlanetaryConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3896 import (
        PlanetaryGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3897 import (
        PlanetCarrierSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3898 import (
        PointLoadSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3899 import (
        PowerLoadSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3900 import (
        PulleySteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3901 import (
        RingPinsSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3902 import (
        RingPinsToDiscConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3903 import (
        RollingRingAssemblySteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3904 import (
        RollingRingConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3905 import (
        RollingRingSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3906 import (
        RootAssemblySteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3907 import (
        ShaftHubConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3908 import (
        ShaftSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3909 import (
        ShaftToMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3910 import (
        SpecialisedAssemblySteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3911 import (
        SpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3912 import (
        SpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3913 import (
        SpiralBevelGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3914 import (
        SpringDamperConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3915 import (
        SpringDamperHalfSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3916 import (
        SpringDamperSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3917 import (
        SteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3918 import (
        StraightBevelDiffGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3919 import (
        StraightBevelDiffGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3920 import (
        StraightBevelDiffGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3921 import (
        StraightBevelGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3922 import (
        StraightBevelGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3923 import (
        StraightBevelGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3924 import (
        StraightBevelPlanetGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3925 import (
        StraightBevelSunGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3926 import (
        SynchroniserHalfSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3927 import (
        SynchroniserPartSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3928 import (
        SynchroniserSleeveSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3929 import (
        SynchroniserSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3930 import (
        TorqueConverterConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3931 import (
        TorqueConverterPumpSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3932 import (
        TorqueConverterSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3933 import (
        TorqueConverterTurbineSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3934 import (
        UnbalancedMassSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3935 import (
        VirtualComponentSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3936 import (
        WormGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3937 import (
        WormGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3938 import (
        WormGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3939 import (
        ZerolBevelGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3940 import (
        ZerolBevelGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3941 import (
        ZerolBevelGearSteadyStateSynchronousResponseAtASpeed,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3810": [
            "AbstractAssemblySteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3811": [
            "AbstractShaftOrHousingSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3812": [
            "AbstractShaftSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3813": [
            "AbstractShaftToMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3814": [
            "AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3815": [
            "AGMAGleasonConicalGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3816": [
            "AGMAGleasonConicalGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3817": [
            "AssemblySteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3818": [
            "BearingSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3819": [
            "BeltConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3820": [
            "BeltDriveSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3821": [
            "BevelDifferentialGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3822": [
            "BevelDifferentialGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3823": [
            "BevelDifferentialGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3824": [
            "BevelDifferentialPlanetGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3825": [
            "BevelDifferentialSunGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3826": [
            "BevelGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3827": [
            "BevelGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3828": [
            "BevelGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3829": [
            "BoltedJointSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3830": [
            "BoltSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3831": [
            "ClutchConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3832": [
            "ClutchHalfSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3833": [
            "ClutchSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3834": [
            "CoaxialConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3835": [
            "ComponentSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3836": [
            "ConceptCouplingConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3837": [
            "ConceptCouplingHalfSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3838": [
            "ConceptCouplingSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3839": [
            "ConceptGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3840": [
            "ConceptGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3841": [
            "ConceptGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3842": [
            "ConicalGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3843": [
            "ConicalGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3844": [
            "ConicalGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3845": [
            "ConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3846": [
            "ConnectorSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3847": [
            "CouplingConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3848": [
            "CouplingHalfSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3849": [
            "CouplingSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3850": [
            "CVTBeltConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3851": [
            "CVTPulleySteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3852": [
            "CVTSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3853": [
            "CycloidalAssemblySteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3854": [
            "CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3855": [
            "CycloidalDiscPlanetaryBearingConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3856": [
            "CycloidalDiscSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3857": [
            "CylindricalGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3858": [
            "CylindricalGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3859": [
            "CylindricalGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3860": [
            "CylindricalPlanetGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3861": [
            "DatumSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3862": [
            "ExternalCADModelSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3863": [
            "FaceGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3864": [
            "FaceGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3865": [
            "FaceGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3866": [
            "FEPartSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3867": [
            "FlexiblePinAssemblySteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3868": [
            "GearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3869": [
            "GearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3870": [
            "GearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3871": [
            "GuideDxfModelSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3872": [
            "HypoidGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3873": [
            "HypoidGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3874": [
            "HypoidGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3875": [
            "InterMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3876": [
            "KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3877": [
            "KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3878": [
            "KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3879": [
            "KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3880": [
            "KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3881": [
            "KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3882": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3883": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3884": [
            "KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3885": [
            "MassDiscSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3886": [
            "MeasurementComponentSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3887": [
            "MicrophoneArraySteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3888": [
            "MicrophoneSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3889": [
            "MountableComponentSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3890": [
            "OilSealSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3891": [
            "PartSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3892": [
            "PartToPartShearCouplingConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3893": [
            "PartToPartShearCouplingHalfSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3894": [
            "PartToPartShearCouplingSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3895": [
            "PlanetaryConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3896": [
            "PlanetaryGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3897": [
            "PlanetCarrierSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3898": [
            "PointLoadSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3899": [
            "PowerLoadSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3900": [
            "PulleySteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3901": [
            "RingPinsSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3902": [
            "RingPinsToDiscConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3903": [
            "RollingRingAssemblySteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3904": [
            "RollingRingConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3905": [
            "RollingRingSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3906": [
            "RootAssemblySteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3907": [
            "ShaftHubConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3908": [
            "ShaftSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3909": [
            "ShaftToMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3910": [
            "SpecialisedAssemblySteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3911": [
            "SpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3912": [
            "SpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3913": [
            "SpiralBevelGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3914": [
            "SpringDamperConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3915": [
            "SpringDamperHalfSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3916": [
            "SpringDamperSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3917": [
            "SteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3918": [
            "StraightBevelDiffGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3919": [
            "StraightBevelDiffGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3920": [
            "StraightBevelDiffGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3921": [
            "StraightBevelGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3922": [
            "StraightBevelGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3923": [
            "StraightBevelGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3924": [
            "StraightBevelPlanetGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3925": [
            "StraightBevelSunGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3926": [
            "SynchroniserHalfSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3927": [
            "SynchroniserPartSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3928": [
            "SynchroniserSleeveSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3929": [
            "SynchroniserSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3930": [
            "TorqueConverterConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3931": [
            "TorqueConverterPumpSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3932": [
            "TorqueConverterSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3933": [
            "TorqueConverterTurbineSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3934": [
            "UnbalancedMassSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3935": [
            "VirtualComponentSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3936": [
            "WormGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3937": [
            "WormGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3938": [
            "WormGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3939": [
            "ZerolBevelGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3940": [
            "ZerolBevelGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3941": [
            "ZerolBevelGearSteadyStateSynchronousResponseAtASpeed"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblySteadyStateSynchronousResponseAtASpeed",
    "AbstractShaftOrHousingSteadyStateSynchronousResponseAtASpeed",
    "AbstractShaftSteadyStateSynchronousResponseAtASpeed",
    "AbstractShaftToMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed",
    "AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseAtASpeed",
    "AGMAGleasonConicalGearSetSteadyStateSynchronousResponseAtASpeed",
    "AGMAGleasonConicalGearSteadyStateSynchronousResponseAtASpeed",
    "AssemblySteadyStateSynchronousResponseAtASpeed",
    "BearingSteadyStateSynchronousResponseAtASpeed",
    "BeltConnectionSteadyStateSynchronousResponseAtASpeed",
    "BeltDriveSteadyStateSynchronousResponseAtASpeed",
    "BevelDifferentialGearMeshSteadyStateSynchronousResponseAtASpeed",
    "BevelDifferentialGearSetSteadyStateSynchronousResponseAtASpeed",
    "BevelDifferentialGearSteadyStateSynchronousResponseAtASpeed",
    "BevelDifferentialPlanetGearSteadyStateSynchronousResponseAtASpeed",
    "BevelDifferentialSunGearSteadyStateSynchronousResponseAtASpeed",
    "BevelGearMeshSteadyStateSynchronousResponseAtASpeed",
    "BevelGearSetSteadyStateSynchronousResponseAtASpeed",
    "BevelGearSteadyStateSynchronousResponseAtASpeed",
    "BoltedJointSteadyStateSynchronousResponseAtASpeed",
    "BoltSteadyStateSynchronousResponseAtASpeed",
    "ClutchConnectionSteadyStateSynchronousResponseAtASpeed",
    "ClutchHalfSteadyStateSynchronousResponseAtASpeed",
    "ClutchSteadyStateSynchronousResponseAtASpeed",
    "CoaxialConnectionSteadyStateSynchronousResponseAtASpeed",
    "ComponentSteadyStateSynchronousResponseAtASpeed",
    "ConceptCouplingConnectionSteadyStateSynchronousResponseAtASpeed",
    "ConceptCouplingHalfSteadyStateSynchronousResponseAtASpeed",
    "ConceptCouplingSteadyStateSynchronousResponseAtASpeed",
    "ConceptGearMeshSteadyStateSynchronousResponseAtASpeed",
    "ConceptGearSetSteadyStateSynchronousResponseAtASpeed",
    "ConceptGearSteadyStateSynchronousResponseAtASpeed",
    "ConicalGearMeshSteadyStateSynchronousResponseAtASpeed",
    "ConicalGearSetSteadyStateSynchronousResponseAtASpeed",
    "ConicalGearSteadyStateSynchronousResponseAtASpeed",
    "ConnectionSteadyStateSynchronousResponseAtASpeed",
    "ConnectorSteadyStateSynchronousResponseAtASpeed",
    "CouplingConnectionSteadyStateSynchronousResponseAtASpeed",
    "CouplingHalfSteadyStateSynchronousResponseAtASpeed",
    "CouplingSteadyStateSynchronousResponseAtASpeed",
    "CVTBeltConnectionSteadyStateSynchronousResponseAtASpeed",
    "CVTPulleySteadyStateSynchronousResponseAtASpeed",
    "CVTSteadyStateSynchronousResponseAtASpeed",
    "CycloidalAssemblySteadyStateSynchronousResponseAtASpeed",
    "CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponseAtASpeed",
    "CycloidalDiscPlanetaryBearingConnectionSteadyStateSynchronousResponseAtASpeed",
    "CycloidalDiscSteadyStateSynchronousResponseAtASpeed",
    "CylindricalGearMeshSteadyStateSynchronousResponseAtASpeed",
    "CylindricalGearSetSteadyStateSynchronousResponseAtASpeed",
    "CylindricalGearSteadyStateSynchronousResponseAtASpeed",
    "CylindricalPlanetGearSteadyStateSynchronousResponseAtASpeed",
    "DatumSteadyStateSynchronousResponseAtASpeed",
    "ExternalCADModelSteadyStateSynchronousResponseAtASpeed",
    "FaceGearMeshSteadyStateSynchronousResponseAtASpeed",
    "FaceGearSetSteadyStateSynchronousResponseAtASpeed",
    "FaceGearSteadyStateSynchronousResponseAtASpeed",
    "FEPartSteadyStateSynchronousResponseAtASpeed",
    "FlexiblePinAssemblySteadyStateSynchronousResponseAtASpeed",
    "GearMeshSteadyStateSynchronousResponseAtASpeed",
    "GearSetSteadyStateSynchronousResponseAtASpeed",
    "GearSteadyStateSynchronousResponseAtASpeed",
    "GuideDxfModelSteadyStateSynchronousResponseAtASpeed",
    "HypoidGearMeshSteadyStateSynchronousResponseAtASpeed",
    "HypoidGearSetSteadyStateSynchronousResponseAtASpeed",
    "HypoidGearSteadyStateSynchronousResponseAtASpeed",
    "InterMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseAtASpeed",
    "MassDiscSteadyStateSynchronousResponseAtASpeed",
    "MeasurementComponentSteadyStateSynchronousResponseAtASpeed",
    "MicrophoneArraySteadyStateSynchronousResponseAtASpeed",
    "MicrophoneSteadyStateSynchronousResponseAtASpeed",
    "MountableComponentSteadyStateSynchronousResponseAtASpeed",
    "OilSealSteadyStateSynchronousResponseAtASpeed",
    "PartSteadyStateSynchronousResponseAtASpeed",
    "PartToPartShearCouplingConnectionSteadyStateSynchronousResponseAtASpeed",
    "PartToPartShearCouplingHalfSteadyStateSynchronousResponseAtASpeed",
    "PartToPartShearCouplingSteadyStateSynchronousResponseAtASpeed",
    "PlanetaryConnectionSteadyStateSynchronousResponseAtASpeed",
    "PlanetaryGearSetSteadyStateSynchronousResponseAtASpeed",
    "PlanetCarrierSteadyStateSynchronousResponseAtASpeed",
    "PointLoadSteadyStateSynchronousResponseAtASpeed",
    "PowerLoadSteadyStateSynchronousResponseAtASpeed",
    "PulleySteadyStateSynchronousResponseAtASpeed",
    "RingPinsSteadyStateSynchronousResponseAtASpeed",
    "RingPinsToDiscConnectionSteadyStateSynchronousResponseAtASpeed",
    "RollingRingAssemblySteadyStateSynchronousResponseAtASpeed",
    "RollingRingConnectionSteadyStateSynchronousResponseAtASpeed",
    "RollingRingSteadyStateSynchronousResponseAtASpeed",
    "RootAssemblySteadyStateSynchronousResponseAtASpeed",
    "ShaftHubConnectionSteadyStateSynchronousResponseAtASpeed",
    "ShaftSteadyStateSynchronousResponseAtASpeed",
    "ShaftToMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed",
    "SpecialisedAssemblySteadyStateSynchronousResponseAtASpeed",
    "SpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed",
    "SpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed",
    "SpiralBevelGearSteadyStateSynchronousResponseAtASpeed",
    "SpringDamperConnectionSteadyStateSynchronousResponseAtASpeed",
    "SpringDamperHalfSteadyStateSynchronousResponseAtASpeed",
    "SpringDamperSteadyStateSynchronousResponseAtASpeed",
    "SteadyStateSynchronousResponseAtASpeed",
    "StraightBevelDiffGearMeshSteadyStateSynchronousResponseAtASpeed",
    "StraightBevelDiffGearSetSteadyStateSynchronousResponseAtASpeed",
    "StraightBevelDiffGearSteadyStateSynchronousResponseAtASpeed",
    "StraightBevelGearMeshSteadyStateSynchronousResponseAtASpeed",
    "StraightBevelGearSetSteadyStateSynchronousResponseAtASpeed",
    "StraightBevelGearSteadyStateSynchronousResponseAtASpeed",
    "StraightBevelPlanetGearSteadyStateSynchronousResponseAtASpeed",
    "StraightBevelSunGearSteadyStateSynchronousResponseAtASpeed",
    "SynchroniserHalfSteadyStateSynchronousResponseAtASpeed",
    "SynchroniserPartSteadyStateSynchronousResponseAtASpeed",
    "SynchroniserSleeveSteadyStateSynchronousResponseAtASpeed",
    "SynchroniserSteadyStateSynchronousResponseAtASpeed",
    "TorqueConverterConnectionSteadyStateSynchronousResponseAtASpeed",
    "TorqueConverterPumpSteadyStateSynchronousResponseAtASpeed",
    "TorqueConverterSteadyStateSynchronousResponseAtASpeed",
    "TorqueConverterTurbineSteadyStateSynchronousResponseAtASpeed",
    "UnbalancedMassSteadyStateSynchronousResponseAtASpeed",
    "VirtualComponentSteadyStateSynchronousResponseAtASpeed",
    "WormGearMeshSteadyStateSynchronousResponseAtASpeed",
    "WormGearSetSteadyStateSynchronousResponseAtASpeed",
    "WormGearSteadyStateSynchronousResponseAtASpeed",
    "ZerolBevelGearMeshSteadyStateSynchronousResponseAtASpeed",
    "ZerolBevelGearSetSteadyStateSynchronousResponseAtASpeed",
    "ZerolBevelGearSteadyStateSynchronousResponseAtASpeed",
)
